[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- pywurfl.ql._Type
  - pywurfl.ql.TypeBool
  - pywurfl.ql.TypeList
  - pywurfl.ql.TypeNone
  - pywurfl.ql.TypeNum
  - pywurfl.ql.TypeStr
- object: The most base type
  - pywurfl.algorithms.wurfl.handlers.AbstractMatcher
    - pywurfl.algorithms.wurfl.handlers.AOLMatcher
    - pywurfl.algorithms.wurfl.handlers.AlcatelMatcher
    - pywurfl.algorithms.wurfl.handlers.AndroidMatcher
    - pywurfl.algorithms.wurfl.handlers.AppleMatcher
    - pywurfl.algorithms.wurfl.handlers.BenQMatcher
    - pywurfl.algorithms.wurfl.handlers.BlackberryMatcher
    - pywurfl.algorithms.wurfl.handlers.BotMatcher
    - pywurfl.algorithms.wurfl.handlers.CatchAllMatcher
    - pywurfl.algorithms.wurfl.handlers.ChromeMatcher
    - pywurfl.algorithms.wurfl.handlers.DoCoMoMatcher
    - pywurfl.algorithms.wurfl.handlers.FirefoxMatcher
    - pywurfl.algorithms.wurfl.handlers.GrundigMatcher
    - pywurfl.algorithms.wurfl.handlers.HTCMatcher
    - pywurfl.algorithms.wurfl.handlers.KDDIMatcher
    - pywurfl.algorithms.wurfl.handlers.KonquerorMatcher
    - pywurfl.algorithms.wurfl.handlers.KyoceraMatcher
    - pywurfl.algorithms.wurfl.handlers.LGMatcher
    - pywurfl.algorithms.wurfl.handlers.LGUPLUSMatcher
    - pywurfl.algorithms.wurfl.handlers.MSIEMatcher
    - pywurfl.algorithms.wurfl.handlers.MaemoMatcher
    - pywurfl.algorithms.wurfl.handlers.MitsubishiMatcher
    - pywurfl.algorithms.wurfl.handlers.MotorolaMatcher
    - pywurfl.algorithms.wurfl.handlers.NecMatcher
    - pywurfl.algorithms.wurfl.handlers.NokiaMatcher
    - pywurfl.algorithms.wurfl.handlers.OperaMatcher
    - pywurfl.algorithms.wurfl.handlers.OperaMiniMatcher
    - pywurfl.algorithms.wurfl.handlers.PanasonicMatcher
    - pywurfl.algorithms.wurfl.handlers.PantechMatcher
    - pywurfl.algorithms.wurfl.handlers.PhilipsMatcher
    - pywurfl.algorithms.wurfl.handlers.PortalmmmMatcher
    - pywurfl.algorithms.wurfl.handlers.QtekMatcher
    - pywurfl.algorithms.wurfl.handlers.SPVMatcher
    - pywurfl.algorithms.wurfl.handlers.SafariMatcher
    - pywurfl.algorithms.wurfl.handlers.SagemMatcher
    - pywurfl.algorithms.wurfl.handlers.SamsungMatcher
    - pywurfl.algorithms.wurfl.handlers.SanyoMatcher
    - pywurfl.algorithms.wurfl.handlers.SharpMatcher
    - pywurfl.algorithms.wurfl.handlers.SiemensMatcher
    - pywurfl.algorithms.wurfl.handlers.SonyEricssonMatcher
    - pywurfl.algorithms.wurfl.handlers.ToshibaMatcher
    - pywurfl.algorithms.wurfl.handlers.VodafoneMatcher
    - pywurfl.algorithms.wurfl.handlers.WindowsCEMatcher
  - pywurfl.algorithms.Algorithm: Base class for all pywurfl search algorithms
    - pywurfl.algorithms.JaroWinkler: Jaro-Winkler Search Algorithm
    - pywurfl.algorithms.LevenshteinDistance: Levenshtein distance Search Algorithm
    - pywurfl.algorithms.Tokenizer: Tokenizer Search Algorithm
    - pywurfl.algorithms.TwoStepAnalysis: WURFL Two Step Analysis algorithm based on the Java API implementation
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - pywurfl.exceptions.WURFLException: pywurfl base exception class.
        - pywurfl.exceptions.ActualDeviceRootNotFound: Actual Device Root Not Found exception class
        - pywurfl.wurflprocessor.DeferredDeviceError: Deferred Device Error Exception
        - pywurfl.exceptions.DeviceNotFound: Device Not Found exception class
        - pywurfl.exceptions.ExistsException: General exception class
        - pywurfl.ql.QueryLanguageError: Base exception class for pywurfl.ql
  - pywurfl.wurflprocessor.DeviceHandler: Base class for DeviceHandler objects
    - wurfl2python.DeviceSerializer
  - pywurfl.Devices: Main pywurfl API class.
  - pywurfl.RootDevice: pywurfl Root Device base class.
  - pywurfl.serialize.Serialize
  - pywurfl.wurflprocessor.WurflProcessor: WURFL Processing Class
    - wurfl2python.WurflPythonWriter